### R code from vignette source 'vix.Rnw'

###################################################
### code chunk number 1: vix.Rnw:67-69
###################################################
# Set the globals options for the R environment.
options(width = 60, str = strOptions(strict.width = "cut"))


###################################################
### code chunk number 2: vix.Rnw:309-321
###################################################
library(ifrogs)
data(vxo_spx)
str(vxo_spx)

vxo(maturity=vxo_spx$maturity,
    riskfree=vxo_spx$riskfree,
    carry=vxo_spx$riskfree,
    type=vxo_spx$type,
    strike=vxo_spx$strike,
    underlying=vxo_spx$underlying,
    bid=vxo_spx$bid,
    ask=vxo_spx$ask)


###################################################
### code chunk number 3: vix.Rnw:326-337
###################################################
data(vxo_nifty)
str(vxo_nifty)

vxo(maturity=vxo_nifty$maturity,
    riskfree=vxo_nifty$riskfree,
    carry=vxo_nifty$riskfree,
    type=vxo_nifty$type,
    strike=vxo_nifty$strike,
    underlying=vxo_nifty$underlying,
    bid=vxo_nifty$bid,
    ask=vxo_nifty$ask)


###################################################
### code chunk number 4: vix.Rnw:411-415
###################################################
data(vix_spx)
str(vix_spx)
data(vix_nifty)
str(vix_nifty)


###################################################
### code chunk number 5: vix.Rnw:420-444
###################################################
spx_near <- prep_maturity(maturity=vix_spx$opt_near$maturity[[1]],
                          riskfree=vix_spx$opt_near$riskfree[[1]],
                          carry=vix_spx$opt_near$riskfree[[1]],
                          type=vix_spx$opt_near$type,
                          strike=vix_spx$opt_near$strike,
                          underlying=vix_spx$opt_near$underlying,
                          schemes="vega",
                          bid=vix_spx$opt_near$bid,
                          ask=vix_spx$opt_near$ask,
                          tv_filter=FALSE)

str(spx_near)

spx_next <- prep_maturity(maturity=vix_spx$opt_next$maturity[[1]],
                          riskfree=vix_spx$opt_next$riskfree[[1]],
                          carry=vix_spx$opt_next$riskfree[[1]],
                          type=vix_spx$opt_next$type,
                          strike=vix_spx$opt_next$strike,
                          underlying=vix_spx$opt_next$underlying,
                          schemes="vega",
                          bid=vix_spx$opt_next$bid,
                          ask=vix_spx$opt_next$ask,
                          tv_filter=FALSE)
str(spx_next)


###################################################
### code chunk number 6: vix.Rnw:452-475
###################################################
nifty_near <- prep_maturity(maturity=vix_nifty$opt_near$maturity[[1]],
                            riskfree=vix_nifty$opt_near$riskfree[[1]],
                            carry=vix_nifty$opt_near$riskfree[[1]],
                            type=vix_nifty$opt_near$type,
                            strike=vix_nifty$opt_near$strike,
                            underlying=vix_nifty$opt_near$underlying,
                            schemes=c("spread", "elasticity", "vega"),
                            bid=vix_nifty$opt_near$bid,
                            ask=vix_nifty$opt_near$ask,
                            traded_vol=vix_nifty$opt_near$traded_vol,
                            tv_filter=TRUE)

nifty_next <- prep_maturity(maturity=vix_nifty$opt_next$maturity[[1]],
                            riskfree=vix_nifty$opt_next$riskfree[[1]],
                            carry=vix_nifty$opt_next$riskfree[[1]],
                            type=vix_nifty$opt_next$type,
                            strike=vix_nifty$opt_next$strike,
                            underlying=vix_nifty$opt_next$underlying,
                            schemes=c("spread", "elasticity", "vega"),
                            bid=vix_nifty$opt_next$bid,
                            ask=vix_nifty$opt_next$ask,
                            traded_vol=vix_nifty$opt_next$traded_vol,
                            tv_filter=TRUE)


###################################################
### code chunk number 7: vix.Rnw:497-500
###################################################
spx_near_iv <- weighted_iv(prepped=spx_near)
spx_next_iv <- weighted_iv(prepped=spx_next)
spx_near_iv


###################################################
### code chunk number 8: vix.Rnw:505-508
###################################################
nifty_near_iv <- weighted_iv(prepped=nifty_near)
nifty_next_iv <- weighted_iv(prepped=nifty_next)
nifty_near_iv


###################################################
### code chunk number 9: vix.Rnw:526-531
###################################################
spx_vix <- vix_pt(iv_near=spx_near_iv, iv_next=spx_next_iv)
spx_vix

nifty_vixes <- vix_pt(iv_near=nifty_near_iv, iv_next=nifty_next_iv)
nifty_vixes


###################################################
### code chunk number 10: vix.Rnw:566-590
###################################################
set.seed(101)
spx_near <- prep_maturity(maturity=vix_spx$opt_near$maturity[[1]],
                            riskfree=vix_spx$opt_near$riskfree[[1]],
                            carry=vix_spx$opt_near$riskfree[[1]],
                            type=vix_spx$opt_near$type,
                            strike=vix_spx$opt_near$strike,
                            underlying=vix_spx$opt_near$underlying,
                            schemes="vega",
                            bid=vix_spx$opt_near$bid,
                            ask=vix_spx$opt_near$ask,
                            traded_vol=NULL,
                            tv_filter=FALSE)

spx_next <- prep_maturity(maturity=vix_spx$opt_next$maturity[[1]],
                            riskfree=vix_spx$opt_next$riskfree[[1]],
                            carry=vix_spx$opt_next$riskfree[[1]],
                            type=vix_spx$opt_next$type,
                            strike=vix_spx$opt_next$strike,
                            underlying=vix_spx$opt_next$underlying,
                            schemes="vega",
                            bid=vix_spx$opt_next$bid,
                            ask=vix_spx$opt_next$ask,
                            traded_vol=NULL,
                            tv_filter=FALSE)


###################################################
### code chunk number 11: vix.Rnw:593-599
###################################################
spx_ci <- vix_ci(prep_near=spx_near,
                 prep_next=spx_next,
                 n_samples=1e3, conf=0.95,
                 verbose=TRUE)

str(spx_ci)


###################################################
### code chunk number 12: vix.Rnw:604-628
###################################################
set.seed(101)
nifty_near <- prep_maturity(maturity=vix_nifty$opt_near$maturity[[1]],
                            riskfree=vix_nifty$opt_near$riskfree[[1]],
                            carry=vix_nifty$opt_near$riskfree[[1]],
                            type=vix_nifty$opt_near$type,
                            strike=vix_nifty$opt_near$strike,
                            underlying=vix_nifty$opt_near$underlying,
                            schemes="vega",
                            bid=vix_nifty$opt_near$bid,
                            ask=vix_nifty$opt_near$ask,
                            traded_vol=vix_nifty$opt_near$traded_vol,
                            tv_filter=TRUE)

nifty_next <- prep_maturity(maturity=vix_nifty$opt_next$maturity[[1]],
                            riskfree=vix_nifty$opt_next$riskfree[[1]],
                            carry=vix_nifty$opt_next$riskfree[[1]],
                            type=vix_nifty$opt_next$type,
                            strike=vix_nifty$opt_next$strike,
                            underlying=vix_nifty$opt_next$underlying,
                            schemes="vega",
                            bid=vix_nifty$opt_next$bid,
                            ask=vix_nifty$opt_next$ask,
                            traded_vol=vix_nifty$opt_next$traded_vol,
                            tv_filter=TRUE)


###################################################
### code chunk number 13: vix.Rnw:631-637
###################################################
nifty_ci <- vix_ci(prep_near=nifty_near,
                   prep_next=nifty_next,
                   n_samples=1e3, conf=0.95,
                   verbose=TRUE)

str(nifty_ci)


